window.Gleam.initSearch([{"doc":"glotel","title":"glotel","content":"# glotel\n\n[![Package Version](https://img.shields.io/hexpm/v/glotel)](https://hex.pm/packages/glotel)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glotel/)\n\n```sh\ngleam add glotel\n```\n\nCurrently supports basic tracing functionality.\n\nDocumentation can be found at &lt;https://hexdocs.pm/glotel&gt;.\n\n## Running an Application\n\nRefer to the [OpenTelemetry environment\nvariables](https://opentelemetry.io/docs/specs/otel/configuration/sdk-environment-variables/)\nfor SDK configuration, e.g.:\n\n```shell\nexport OTEL_SERVICE_NAME=&quot;your_application&quot;\nexport OTEL_EXPORTER_OTLP_ENDPOINT=&quot;http://localhost:4318&quot;\nexport OTEL_EXPORTER_OTLP_HEADERS=&quot;x-service-api-key=12345&quot;\ngleam run\n```\n\n### Testing an Application\n\nThis command will launch a Jaeger instance for collecting traces during local\ndevelopment on port 4318, with a web portal for viewing at\n[http://localhost:16686/](http://localhost:16686/).\n\n```shell\ndocker run --rm --name jaeger \\\n  -e COLLECTOR_ZIPKIN_HOST_PORT=:9411 \\\n  -p 6831:6831/udp \\\n  -p 6832:6832/udp \\\n  -p 5778:5778 \\\n  -p 16686:16686 \\\n  -p 4317:4317 \\\n  -p 4318:4318 \\\n  -p 14250:14250 \\\n  -p 14268:14268 \\\n  -p 14269:14269 \\\n  -p 9411:9411 \\\n  jaegertracing/all-in-one:1.56\n```\n\n\n## Known Quirks\n\nThere may be a warning on application startup that the OTLP exporter failed to\nstart, and then successfully starts, e.g.:\n\n```\nOTLP exporter failed to initialize with exception error:{badmatch,\n                                                         {error,\n                                                          inets_not_started}}\n...\nINFO OTLP exporter successfully initialized\n```\n\n## Basic Examples\n\n```gleam\nimport glotel/span\n\npub fn foo() {\n  use span_ctx &lt;- span.new(&quot;span_name&quot;, [#(&quot;attribute&quot;, &quot;value&quot;)])\n  ...\n}\n\npub fn bar_error() {\n  use span_ctx &lt;- span.new(&quot;span_name&quot;, [])\n  span.set_error_message(span_ctx, &quot;Descriptive error message&quot;)\n  ...\n}\n\npub fn baz_try_error() {\n  use span_ctx &lt;- span.new(&quot;span_name&quot;, [])\n  use baz &lt;- span.try_with_message(\n    span_ctx,\n    &quot;Failed to baz&quot;,\n    Error(&quot;Descriptive error message&quot;),\n  )\n  ...\n}\n```\n\n## Example Wisp Middleware\n\n```gleam\nimport gleam/http.{method_to_string}\nimport gleam/int\nimport glotel/span\nimport glotel/span_kind\nimport wisp.{type Request, type Response}\n\npub fn trace_middleware(request: Request, handler: fn() -&gt; Response) -&gt; Response {\n  let method = method_to_string(request.method)\n  let path = request.path\n\n  span.extract_values(request.headers)\n\n  use span_ctx &lt;- span.new_of_kind(span_kind.Server, method &lt;&gt; &quot; &quot; &lt;&gt; path, [\n    #(&quot;http.method&quot;, method),\n    #(&quot;http.route&quot;, path),\n  ])\n\n  let response = handler()\n\n  span.set_attribute(\n    span_ctx,\n    &quot;http.status_code&quot;,\n    int.to_string(response.status),\n  )\n\n  case response.status &gt;= 500 {\n    True -&gt; span.set_error(span_ctx)\n    _ -&gt; Nil\n  }\n\n  response\n}\n```\n\n","url":"index.html"},{"doc":"glotel/span_kind","title":"SpanKind","content":"pub type SpanKind {\n  Client\n  Server\n  Producer\n  Consumer\n  Internal\n}\n\nClient\n\n\nServer\n\n\nProducer\n\n\nConsumer\n\n\nInternal\n\n\nSynonyms:\nglotel/span_kind.SpanKind\nglotel/span_kind SpanKind","url":"glotel/span_kind.html#SpanKind"},{"doc":"glotel/span_kind","title":"glotel/span_kind","content":"","url":"glotel/span_kind.html"},{"doc":"glotel/span_status_code","title":"SpanStatusCode","content":"pub type SpanStatusCode {\n  Unset\n  Ok\n  Error\n}\n\nUnset\n\n\nOk\n\n\nError\n\n\nSynonyms:\nglotel/span_status_code.SpanStatusCode\nglotel/span_status_code SpanStatusCode","url":"glotel/span_status_code.html#SpanStatusCode"},{"doc":"glotel/span_status_code","title":"glotel/span_status_code","content":"","url":"glotel/span_status_code.html"},{"doc":"glotel/span","title":"SpanContext","content":"pub type SpanContext\n An OpenTelemetry span context\n \n\nSynonyms:\nglotel/span.SpanContext\nglotel/span SpanContext","url":"glotel/span.html#SpanContext"},{"doc":"glotel/span","title":"extract_values","content":"pub fn extract_values(values: List(#(String, String))) -&gt; Nil\n Extract OpenTelemetry attributes like `traceparent` from request headers.\n \n ## Examples\n \n \n pub fn trace_middleware(request: Request, handler: fn() -&gt; Response) -&gt; Response {\n   extract_values(request.headers)\n }\n \n \nSynonyms:\nglotel/span.extract_values\nglotel/span extract_values","url":"glotel/span.html#extract_values"},{"doc":"glotel/span","title":"new","content":"pub fn new(\n  name: String,\n  attributes: List(#(String, String)),\n  apply: fn(SpanContext) -&gt; a,\n) -&gt; a\n Creates a new span context, automatically linked to its immediate parent span, if present.\n Default to a internal span kind.\n \n ## Examples\n \n \n fn foo() {\n     use span_ctx &lt;- new(&quot;foo&quot;, [#(&quot;attribute&quot;, &quot;value&quot;)])\n }\n \n \nSynonyms:\nglotel/span.new\nglotel/span new","url":"glotel/span.html#new"},{"doc":"glotel/span","title":"new_of_kind","content":"pub fn new_of_kind(\n  kind: SpanKind,\n  name: String,\n  attributes: List(#(String, String)),\n  apply: fn(SpanContext) -&gt; a,\n) -&gt; a\n Same as `new`, but allows specifying span kind.\n \n ## Examples\n \n \n fn server_foo() {\n   use span_ctx &lt;- new_of_kind(span_kind.Server, &quot;server_foo&quot;, [\n     #(&quot;attribute&quot;, &quot;value&quot;),\n   ])\n }\n \n \nSynonyms:\nglotel/span.new_of_kind\nglotel/span new_of_kind","url":"glotel/span.html#new_of_kind"},{"doc":"glotel/span","title":"set_attribute","content":"pub fn set_attribute(\n  span: SpanContext,\n  key: String,\n  value: String,\n) -&gt; Nil\n Sets an additional attribute on a given span.\n \n ## Examples\n \n \n fn foo() {\n   use span_ctx &lt;- new(&quot;foo&quot;, [])\n   set_attribute(span_ctx, &quot;bar&quot;, &quot;baz&quot;)\n }\n \n \nSynonyms:\nglotel/span.set_attribute\nglotel/span set_attribute","url":"glotel/span.html#set_attribute"},{"doc":"glotel/span","title":"set_error","content":"pub fn set_error(span: SpanContext) -&gt; Nil\n Sets `error = true` on a given span.\n \n ## Examples\n \n \n case status_code &gt;= 500 {\n   True -&gt; set_error(span_ctx)\n   False -&gt; Nil\n }\n \n \nSynonyms:\nglotel/span.set_error\nglotel/span set_error","url":"glotel/span.html#set_error"},{"doc":"glotel/span","title":"set_error_message","content":"pub fn set_error_message(\n  span: SpanContext,\n  message: String,\n) -&gt; Nil\n Same as `set_error`, but allows specifying an explicit error message.\n \n ## Examples\n \n \n case status_code &gt;= 500 {\n   True -&gt;\n     set_error_message(\n       span_ctx,\n       &quot;Request error: &quot; &lt;&gt; int.to_string(status_code),\n     )\n   False -&gt; Nil\n }\n \n \nSynonyms:\nglotel/span.set_error_message\nglotel/span set_error_message","url":"glotel/span.html#set_error_message"},{"doc":"glotel/span","title":"try","content":"pub fn try(\n  span: SpanContext,\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n Same as standard library `result.try()`,\n but automatically calls `set_error(span)` on an Error.\n \nSynonyms:\nglotel/span.try\nglotel/span try","url":"glotel/span.html#try"},{"doc":"glotel/span","title":"try_with_message","content":"pub fn try_with_message(\n  span: SpanContext,\n  message: String,\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n Same as standard library `result.try()`,\n but automatically calls `set_error_message(span, message)` on an Error.\n \nSynonyms:\nglotel/span.try_with_message\nglotel/span try_with_message","url":"glotel/span.html#try_with_message"},{"doc":"glotel/span","title":"glotel/span","content":"","url":"glotel/span.html"}]);